==> knetdockapp_0.82.orig.tar.gz: knetdockapp-0.82/src/knetdockapp.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Todor Gyumyushev   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KNETDOCKAPP_H
#define KNETDOCKAPP_H
#include <kuniqueapplication.h>
/**
	@author Todor Gyumyushev <yodor@developer.bg>
*/
class KNetDockApp : public KUniqueApplication
{
public:
    KNetDockApp();
    ~KNetDockApp();

	virtual int newInstance();

};

#endif

==> knetdockapp_0.82.3.orig.tar.gz: knetdockapp-0.82.3/src/knetdockapp.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Todor Gyumyushev   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KNETDOCKAPP_H
#define KNETDOCKAPP_H
#include <kuniqueapplication.h>
/**
	@author Todor Gyumyushev <yodor@developer.bg>
*/
class KNetDockApp : public KApplication
{
public:
    KNetDockApp();
    ~KNetDockApp();

	virtual int newInstance();

};

#endif
